#!/bin/sh
# Name: mgcamd-complete_1.30a_delfile.sh
# Version: 1.30a
# Type: Cam

killall -9 cs_clnt cs_srv newcs_1.50 mgcamd_1.30a 2>/dev/null

rm -rf /var/bin/mgcamd_1.30a
rm -rf /var/bin/newcs_1.50 
rm -rf /var/script/mgcamd_1.30a_cam.sh
rm -rf /var/script/mgcamd_1.30a_newcs_1.50_cam.sh
rm -rf /var/tuxbox/config/newcs.xml 
rm -rf /var/keys/mg_cfg
rm -rf /var/keys/newcamd.list
rm -rf /var/keys/priority.list
rm -rf /var/keys/ignore.list
rm -rf /var/uninstall/mgcamd-complete_1.30a_delfile.sh

exit 0